@@ -1,5 +1,4 @@
-from typing import Tuple, Union, Literal
-
+from typing import Literal, Tuple, Union
 
 ModeType = Literal[
     "1", "CMYK", "F", "HSV", "I", "L", "LAB", "P", "RGB", "RGBA", "RGBX", "YCbCr"
@@ -26,8 +25,5 @@ DirectionType = Literal[
     "southwest",
     "southeast",
 ]
-ResampleType = Literal[0, 1, 2, 3, 4, 5]
-TransposeType = Literal[0, 1, 2, 3, 4, 5, 6]
-
 FontStyle = Literal["normal", "italic", "oblique"]
 FontWeight = Literal["ultralight", "light", "normal", "bold", "ultrabold", "heavy"]
